==> org.eclipse.jgit-5.2.1.201812262042-r-sources.jar: org/eclipse/jgit/transport/RefFilter.java <==
/*
 * Copyright (C) 2010, Google Inc.
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.eclipse.jgit.transport;

import java.util.Map;

import org.eclipse.jgit.lib.Ref;

/**
 * Filters the list of refs that are advertised to the client.
 * <p>
 * The filter is called by {@link org.eclipse.jgit.transport.ReceivePack} and
 * {@link org.eclipse.jgit.transport.UploadPack} to ensure that the refs are
 * filtered before they are advertised to the client.
 * <p>
 * This can be used by applications to control visibility of certain refs based
 * on a custom set of rules.
 */
public interface RefFilter {
	/**
	 * The default filter, allows all refs to be shown.
	 */
	RefFilter DEFAULT = new RefFilter() {
		@Override
		public Map<String, Ref> filter (Map<String, Ref> refs) {
			return refs;
		}
	};

	/**
	 * Filters a {@code Map} of refs before it is advertised to the client.
	 *
	 * @param refs
	 *            the refs which this method need to consider.
	 * @return
	 *            the filtered map of refs.
	 */
	Map<String, Ref> filter(Map<String, Ref> refs);
}

==> org.eclipse.jgit-5.5.1.201910021850-r-sources.jar: org/eclipse/jgit/transport/RefFilter.java <==
/*
 * Copyright (C) 2010, Google Inc.
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.eclipse.jgit.transport;

import java.util.Map;

import org.eclipse.jgit.lib.Ref;

/**
 * Filters the list of refs that are advertised to the client.
 * <p>
 * The filter is called by {@link org.eclipse.jgit.transport.ReceivePack} and
 * {@link org.eclipse.jgit.transport.UploadPack} to ensure that the refs are
 * filtered before they are advertised to the client.
 * <p>
 * This can be used by applications to control visibility of certain refs based
 * on a custom set of rules.
 */
public interface RefFilter {
	/**
	 * The default filter, allows all refs to be shown.
	 */
	RefFilter DEFAULT = (Map<String, Ref> refs) -> refs;

	/**
	 * Filters a {@code Map} of refs before it is advertised to the client.
	 *
	 * @param refs
	 *            the refs which this method need to consider.
	 * @return
	 *            the filtered map of refs.
	 */
	Map<String, Ref> filter(Map<String, Ref> refs);
}
